# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicecontrol/v1/service_controller.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api.servicecontrol.v1 import check_error_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_check__error__pb2
from google.api.servicecontrol.v1 import operation_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_operation__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/servicecontrol/v1/service_controller.proto',
  package='google.api.servicecontrol.v1',
  syntax='proto3',
  serialized_options=b'\n com.google.api.servicecontrol.v1B\026ServiceControllerProtoP\001ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\370\001\001\242\002\004GASC',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5google/api/servicecontrol/v1/service_controller.proto\x12\x1cgoogle.api.servicecontrol.v1\x1a\x1cgoogle/api/annotations.proto\x1a.google/api/servicecontrol/v1/check_error.proto\x1a,google/api/servicecontrol/v1/operation.proto\x1a\x17google/rpc/status.proto\"{\n\x0c\x43heckRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12:\n\toperation\x18\x02 \x01(\x0b\x32\'.google.api.servicecontrol.v1.Operation\x12\x19\n\x11service_config_id\x18\x04 \x01(\t\"\xed\x02\n\rCheckResponse\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\x1a\n\x12service_rollout_id\x18\x0b \x01(\t\x12>\n\x0c\x63heck_errors\x18\x02 \x03(\x0b\x32(.google.api.servicecontrol.v1.CheckError\x12\x19\n\x11service_config_id\x18\x05 \x01(\t\x12I\n\ncheck_info\x18\x06 \x01(\x0b\x32\x35.google.api.servicecontrol.v1.CheckResponse.CheckInfo\x1a\\\n\tCheckInfo\x12O\n\rconsumer_info\x18\x02 \x01(\x0b\x32\x38.google.api.servicecontrol.v1.CheckResponse.ConsumerInfo\x1a&\n\x0c\x43onsumerInfo\x12\x16\n\x0eproject_number\x18\x01 \x01(\x03\"}\n\rReportRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12;\n\noperations\x18\x02 \x03(\x0b\x32\'.google.api.servicecontrol.v1.Operation\x12\x19\n\x11service_config_id\x18\x03 \x01(\t\"\xe1\x01\n\x0eReportResponse\x12O\n\rreport_errors\x18\x01 \x03(\x0b\x32\x38.google.api.servicecontrol.v1.ReportResponse.ReportError\x12\x19\n\x11service_config_id\x18\x02 \x01(\t\x12\x1a\n\x12service_rollout_id\x18\x04 \x01(\t\x1aG\n\x0bReportError\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\"\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status2\xb9\x02\n\x11ServiceController\x12\x8e\x01\n\x05\x43heck\x12*.google.api.servicecontrol.v1.CheckRequest\x1a+.google.api.servicecontrol.v1.CheckResponse\",\x82\xd3\xe4\x93\x02&\"!/v1/services/{service_name}:check:\x01*\x12\x92\x01\n\x06Report\x12+.google.api.servicecontrol.v1.ReportRequest\x1a,.google.api.servicecontrol.v1.ReportResponse\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/services/{service_name}:report:\x01*B\x92\x01\n com.google.api.servicecontrol.v1B\x16ServiceControllerProtoP\x01ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\xf8\x01\x01\xa2\x02\x04GASCb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_servicecontrol_dot_v1_dot_check__error__pb2.DESCRIPTOR,google_dot_api_dot_servicecontrol_dot_v1_dot_operation__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_CHECKREQUEST = _descriptor.Descriptor(
  name='CheckRequest',
  full_name='google.api.servicecontrol.v1.CheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicecontrol.v1.CheckRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='google.api.servicecontrol.v1.CheckRequest.operation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_config_id', full_name='google.api.servicecontrol.v1.CheckRequest.service_config_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=359,
)


_CHECKRESPONSE_CHECKINFO = _descriptor.Descriptor(
  name='CheckInfo',
  full_name='google.api.servicecontrol.v1.CheckResponse.CheckInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='consumer_info', full_name='google.api.servicecontrol.v1.CheckResponse.CheckInfo.consumer_info', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=687,
)

_CHECKRESPONSE_CONSUMERINFO = _descriptor.Descriptor(
  name='ConsumerInfo',
  full_name='google.api.servicecontrol.v1.CheckResponse.ConsumerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_number', full_name='google.api.servicecontrol.v1.CheckResponse.ConsumerInfo.project_number', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=689,
  serialized_end=727,
)

_CHECKRESPONSE = _descriptor.Descriptor(
  name='CheckResponse',
  full_name='google.api.servicecontrol.v1.CheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_id', full_name='google.api.servicecontrol.v1.CheckResponse.operation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_rollout_id', full_name='google.api.servicecontrol.v1.CheckResponse.service_rollout_id', index=1,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='check_errors', full_name='google.api.servicecontrol.v1.CheckResponse.check_errors', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_config_id', full_name='google.api.servicecontrol.v1.CheckResponse.service_config_id', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='check_info', full_name='google.api.servicecontrol.v1.CheckResponse.check_info', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHECKRESPONSE_CHECKINFO, _CHECKRESPONSE_CONSUMERINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=362,
  serialized_end=727,
)


_REPORTREQUEST = _descriptor.Descriptor(
  name='ReportRequest',
  full_name='google.api.servicecontrol.v1.ReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicecontrol.v1.ReportRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.api.servicecontrol.v1.ReportRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_config_id', full_name='google.api.servicecontrol.v1.ReportRequest.service_config_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=854,
)


_REPORTRESPONSE_REPORTERROR = _descriptor.Descriptor(
  name='ReportError',
  full_name='google.api.servicecontrol.v1.ReportResponse.ReportError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_id', full_name='google.api.servicecontrol.v1.ReportResponse.ReportError.operation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.api.servicecontrol.v1.ReportResponse.ReportError.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1011,
  serialized_end=1082,
)

_REPORTRESPONSE = _descriptor.Descriptor(
  name='ReportResponse',
  full_name='google.api.servicecontrol.v1.ReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='report_errors', full_name='google.api.servicecontrol.v1.ReportResponse.report_errors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_config_id', full_name='google.api.servicecontrol.v1.ReportResponse.service_config_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_rollout_id', full_name='google.api.servicecontrol.v1.ReportResponse.service_rollout_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REPORTRESPONSE_REPORTERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=1082,
)

_CHECKREQUEST.fields_by_name['operation'].message_type = google_dot_api_dot_servicecontrol_dot_v1_dot_operation__pb2._OPERATION
_CHECKRESPONSE_CHECKINFO.fields_by_name['consumer_info'].message_type = _CHECKRESPONSE_CONSUMERINFO
_CHECKRESPONSE_CHECKINFO.containing_type = _CHECKRESPONSE
_CHECKRESPONSE_CONSUMERINFO.containing_type = _CHECKRESPONSE
_CHECKRESPONSE.fields_by_name['check_errors'].message_type = google_dot_api_dot_servicecontrol_dot_v1_dot_check__error__pb2._CHECKERROR
_CHECKRESPONSE.fields_by_name['check_info'].message_type = _CHECKRESPONSE_CHECKINFO
_REPORTREQUEST.fields_by_name['operations'].message_type = google_dot_api_dot_servicecontrol_dot_v1_dot_operation__pb2._OPERATION
_REPORTRESPONSE_REPORTERROR.fields_by_name['status'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_REPORTRESPONSE_REPORTERROR.containing_type = _REPORTRESPONSE
_REPORTRESPONSE.fields_by_name['report_errors'].message_type = _REPORTRESPONSE_REPORTERROR
DESCRIPTOR.message_types_by_name['CheckRequest'] = _CHECKREQUEST
DESCRIPTOR.message_types_by_name['CheckResponse'] = _CHECKRESPONSE
DESCRIPTOR.message_types_by_name['ReportRequest'] = _REPORTREQUEST
DESCRIPTOR.message_types_by_name['ReportResponse'] = _REPORTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CheckRequest = _reflection.GeneratedProtocolMessageType('CheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKREQUEST,
  '__module__' : 'google.api.servicecontrol.v1.service_controller_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.CheckRequest)
  })
_sym_db.RegisterMessage(CheckRequest)

CheckResponse = _reflection.GeneratedProtocolMessageType('CheckResponse', (_message.Message,), {

  'CheckInfo' : _reflection.GeneratedProtocolMessageType('CheckInfo', (_message.Message,), {
    'DESCRIPTOR' : _CHECKRESPONSE_CHECKINFO,
    '__module__' : 'google.api.servicecontrol.v1.service_controller_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.CheckResponse.CheckInfo)
    })
  ,

  'ConsumerInfo' : _reflection.GeneratedProtocolMessageType('ConsumerInfo', (_message.Message,), {
    'DESCRIPTOR' : _CHECKRESPONSE_CONSUMERINFO,
    '__module__' : 'google.api.servicecontrol.v1.service_controller_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.CheckResponse.ConsumerInfo)
    })
  ,
  'DESCRIPTOR' : _CHECKRESPONSE,
  '__module__' : 'google.api.servicecontrol.v1.service_controller_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.CheckResponse)
  })
_sym_db.RegisterMessage(CheckResponse)
_sym_db.RegisterMessage(CheckResponse.CheckInfo)
_sym_db.RegisterMessage(CheckResponse.ConsumerInfo)

ReportRequest = _reflection.GeneratedProtocolMessageType('ReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTREQUEST,
  '__module__' : 'google.api.servicecontrol.v1.service_controller_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.ReportRequest)
  })
_sym_db.RegisterMessage(ReportRequest)

ReportResponse = _reflection.GeneratedProtocolMessageType('ReportResponse', (_message.Message,), {

  'ReportError' : _reflection.GeneratedProtocolMessageType('ReportError', (_message.Message,), {
    'DESCRIPTOR' : _REPORTRESPONSE_REPORTERROR,
    '__module__' : 'google.api.servicecontrol.v1.service_controller_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.ReportResponse.ReportError)
    })
  ,
  'DESCRIPTOR' : _REPORTRESPONSE,
  '__module__' : 'google.api.servicecontrol.v1.service_controller_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.ReportResponse)
  })
_sym_db.RegisterMessage(ReportResponse)
_sym_db.RegisterMessage(ReportResponse.ReportError)


DESCRIPTOR._options = None

_SERVICECONTROLLER = _descriptor.ServiceDescriptor(
  name='ServiceController',
  full_name='google.api.servicecontrol.v1.ServiceController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1085,
  serialized_end=1398,
  methods=[
  _descriptor.MethodDescriptor(
    name='Check',
    full_name='google.api.servicecontrol.v1.ServiceController.Check',
    index=0,
    containing_service=None,
    input_type=_CHECKREQUEST,
    output_type=_CHECKRESPONSE,
    serialized_options=b'\202\323\344\223\002&\"!/v1/services/{service_name}:check:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Report',
    full_name='google.api.servicecontrol.v1.ServiceController.Report',
    index=1,
    containing_service=None,
    input_type=_REPORTREQUEST,
    output_type=_REPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002\'\"\"/v1/services/{service_name}:report:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVICECONTROLLER)

DESCRIPTOR.services_by_name['ServiceController'] = _SERVICECONTROLLER

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/upstreams/http/tcp/v3/tcp_connection_pool.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/upstreams/http/tcp/v3/tcp_connection_pool.proto',
  package='envoy.extensions.upstreams.http.tcp.v3',
  syntax='proto3',
  serialized_options=b'\n4io.envoyproxy.envoy.extensions.upstreams.http.tcp.v3B TcpConnectionPoolProtoOuterClassP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@envoy/extensions/upstreams/http/tcp/v3/tcp_connection_pool.proto\x12&envoy.extensions.upstreams.http.tcp.v3\x1a\x1dudpa/annotations/status.proto\"\x18\n\x16TcpConnectionPoolProtoBb\n4io.envoyproxy.envoy.extensions.upstreams.http.tcp.v3B TcpConnectionPoolProtoOuterClassP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_TCPCONNECTIONPOOLPROTO = _descriptor.Descriptor(
  name='TcpConnectionPoolProto',
  full_name='envoy.extensions.upstreams.http.tcp.v3.TcpConnectionPoolProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=163,
)

DESCRIPTOR.message_types_by_name['TcpConnectionPoolProto'] = _TCPCONNECTIONPOOLPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TcpConnectionPoolProto = _reflection.GeneratedProtocolMessageType('TcpConnectionPoolProto', (_message.Message,), {
  'DESCRIPTOR' : _TCPCONNECTIONPOOLPROTO,
  '__module__' : 'envoy.extensions.upstreams.http.tcp.v3.tcp_connection_pool_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.http.tcp.v3.TcpConnectionPoolProto)
  })
_sym_db.RegisterMessage(TcpConnectionPoolProto)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1beta1/eval.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1beta1 import value_pb2 as google_dot_api_dot_expr_dot_v1beta1_dot_value__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/expr/v1beta1/eval.proto',
  package='google.api.expr.v1beta1',
  syntax='proto3',
  serialized_options=b'\n\033com.google.api.expr.v1beta1B\tEvalProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"google/api/expr/v1beta1/eval.proto\x12\x17google.api.expr.v1beta1\x1a#google/api/expr/v1beta1/value.proto\x1a\x17google/rpc/status.proto\"\xc2\x01\n\tEvalState\x12\x32\n\x06values\x18\x01 \x03(\x0b\x32\".google.api.expr.v1beta1.ExprValue\x12:\n\x07results\x18\x03 \x03(\x0b\x32).google.api.expr.v1beta1.EvalState.Result\x1a\x45\n\x06Result\x12,\n\x04\x65xpr\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1beta1.IdRef\x12\r\n\x05value\x18\x02 \x01(\x05\"\xb0\x01\n\tExprValue\x12/\n\x05value\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1beta1.ValueH\x00\x12\x32\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.google.api.expr.v1beta1.ErrorSetH\x00\x12\x36\n\x07unknown\x18\x03 \x01(\x0b\x32#.google.api.expr.v1beta1.UnknownSetH\x00\x42\x06\n\x04kind\".\n\x08\x45rrorSet\x12\"\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x12.google.rpc.Status\";\n\nUnknownSet\x12-\n\x05\x65xprs\x18\x01 \x03(\x0b\x32\x1e.google.api.expr.v1beta1.IdRef\"\x13\n\x05IdRef\x12\n\n\x02id\x18\x01 \x01(\x05\x42j\n\x1b\x63om.google.api.expr.v1beta1B\tEvalProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_expr_dot_v1beta1_dot_value__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_EVALSTATE_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='google.api.expr.v1beta1.EvalState.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='expr', full_name='google.api.expr.v1beta1.EvalState.Result.expr', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1beta1.EvalState.Result.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=320,
)

_EVALSTATE = _descriptor.Descriptor(
  name='EvalState',
  full_name='google.api.expr.v1beta1.EvalState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='google.api.expr.v1beta1.EvalState.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.api.expr.v1beta1.EvalState.results', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EVALSTATE_RESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=320,
)


_EXPRVALUE = _descriptor.Descriptor(
  name='ExprValue',
  full_name='google.api.expr.v1beta1.ExprValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1beta1.ExprValue.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='google.api.expr.v1beta1.ExprValue.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unknown', full_name='google.api.expr.v1beta1.ExprValue.unknown', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='google.api.expr.v1beta1.ExprValue.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=323,
  serialized_end=499,
)


_ERRORSET = _descriptor.Descriptor(
  name='ErrorSet',
  full_name='google.api.expr.v1beta1.ErrorSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='google.api.expr.v1beta1.ErrorSet.errors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=547,
)


_UNKNOWNSET = _descriptor.Descriptor(
  name='UnknownSet',
  full_name='google.api.expr.v1beta1.UnknownSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exprs', full_name='google.api.expr.v1beta1.UnknownSet.exprs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=549,
  serialized_end=608,
)


_IDREF = _descriptor.Descriptor(
  name='IdRef',
  full_name='google.api.expr.v1beta1.IdRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.expr.v1beta1.IdRef.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=610,
  serialized_end=629,
)

_EVALSTATE_RESULT.fields_by_name['expr'].message_type = _IDREF
_EVALSTATE_RESULT.containing_type = _EVALSTATE
_EVALSTATE.fields_by_name['values'].message_type = _EXPRVALUE
_EVALSTATE.fields_by_name['results'].message_type = _EVALSTATE_RESULT
_EXPRVALUE.fields_by_name['value'].message_type = google_dot_api_dot_expr_dot_v1beta1_dot_value__pb2._VALUE
_EXPRVALUE.fields_by_name['error'].message_type = _ERRORSET
_EXPRVALUE.fields_by_name['unknown'].message_type = _UNKNOWNSET
_EXPRVALUE.oneofs_by_name['kind'].fields.append(
  _EXPRVALUE.fields_by_name['value'])
_EXPRVALUE.fields_by_name['value'].containing_oneof = _EXPRVALUE.oneofs_by_name['kind']
_EXPRVALUE.oneofs_by_name['kind'].fields.append(
  _EXPRVALUE.fields_by_name['error'])
_EXPRVALUE.fields_by_name['error'].containing_oneof = _EXPRVALUE.oneofs_by_name['kind']
_EXPRVALUE.oneofs_by_name['kind'].fields.append(
  _EXPRVALUE.fields_by_name['unknown'])
_EXPRVALUE.fields_by_name['unknown'].containing_oneof = _EXPRVALUE.oneofs_by_name['kind']
_ERRORSET.fields_by_name['errors'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_UNKNOWNSET.fields_by_name['exprs'].message_type = _IDREF
DESCRIPTOR.message_types_by_name['EvalState'] = _EVALSTATE
DESCRIPTOR.message_types_by_name['ExprValue'] = _EXPRVALUE
DESCRIPTOR.message_types_by_name['ErrorSet'] = _ERRORSET
DESCRIPTOR.message_types_by_name['UnknownSet'] = _UNKNOWNSET
DESCRIPTOR.message_types_by_name['IdRef'] = _IDREF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EvalState = _reflection.GeneratedProtocolMessageType('EvalState', (_message.Message,), {

  'Result' : _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
    'DESCRIPTOR' : _EVALSTATE_RESULT,
    '__module__' : 'google.api.expr.v1beta1.eval_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.EvalState.Result)
    })
  ,
  'DESCRIPTOR' : _EVALSTATE,
  '__module__' : 'google.api.expr.v1beta1.eval_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.EvalState)
  })
_sym_db.RegisterMessage(EvalState)
_sym_db.RegisterMessage(EvalState.Result)

ExprValue = _reflection.GeneratedProtocolMessageType('ExprValue', (_message.Message,), {
  'DESCRIPTOR' : _EXPRVALUE,
  '__module__' : 'google.api.expr.v1beta1.eval_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.ExprValue)
  })
_sym_db.RegisterMessage(ExprValue)

ErrorSet = _reflection.GeneratedProtocolMessageType('ErrorSet', (_message.Message,), {
  'DESCRIPTOR' : _ERRORSET,
  '__module__' : 'google.api.expr.v1beta1.eval_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.ErrorSet)
  })
_sym_db.RegisterMessage(ErrorSet)

UnknownSet = _reflection.GeneratedProtocolMessageType('UnknownSet', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWNSET,
  '__module__' : 'google.api.expr.v1beta1.eval_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.UnknownSet)
  })
_sym_db.RegisterMessage(UnknownSet)

IdRef = _reflection.GeneratedProtocolMessageType('IdRef', (_message.Message,), {
  'DESCRIPTOR' : _IDREF,
  '__module__' : 'google.api.expr.v1beta1.eval_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.IdRef)
  })
_sym_db.RegisterMessage(IdRef)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/metrics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v2alpha/metrics.proto',
  package='envoy.admin.v2alpha',
  syntax='proto3',
  serialized_options=b'\n!io.envoyproxy.envoy.admin.v2alphaB\014MetricsProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/admin/v2alpha/metrics.proto\x12\x13\x65nvoy.admin.v2alpha\x1a\x1dudpa/annotations/status.proto\"\x81\x01\n\x0cSimpleMetric\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.envoy.admin.v2alpha.SimpleMetric.Type\x12\r\n\x05value\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x1e\n\x04Type\x12\x0b\n\x07\x43OUNTER\x10\x00\x12\t\n\x05GAUGE\x10\x01\x42;\n!io.envoyproxy.envoy.admin.v2alphaB\x0cMetricsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])



_SIMPLEMETRIC_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='envoy.admin.v2alpha.SimpleMetric.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COUNTER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAUGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=189,
  serialized_end=219,
)
_sym_db.RegisterEnumDescriptor(_SIMPLEMETRIC_TYPE)


_SIMPLEMETRIC = _descriptor.Descriptor(
  name='SimpleMetric',
  full_name='envoy.admin.v2alpha.SimpleMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='envoy.admin.v2alpha.SimpleMetric.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.admin.v2alpha.SimpleMetric.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.SimpleMetric.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIMPLEMETRIC_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=219,
)

_SIMPLEMETRIC.fields_by_name['type'].enum_type = _SIMPLEMETRIC_TYPE
_SIMPLEMETRIC_TYPE.containing_type = _SIMPLEMETRIC
DESCRIPTOR.message_types_by_name['SimpleMetric'] = _SIMPLEMETRIC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimpleMetric = _reflection.GeneratedProtocolMessageType('SimpleMetric', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLEMETRIC,
  '__module__' : 'envoy.admin.v2alpha.metrics_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.SimpleMetric)
  })
_sym_db.RegisterMessage(SimpleMetric)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/route/v4alpha/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.core.v4alpha import config_source_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2
from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/route/v4alpha/route.proto',
  package='envoy.config.route.v4alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.config.route.v4alphaB\nRouteProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&envoy/config/route/v4alpha/route.proto\x12\x1a\x65nvoy.config.route.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a-envoy/config/core/v4alpha/config_source.proto\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xc1\x05\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\rvirtual_hosts\x18\x02 \x03(\x0b\x32\'.envoy.config.route.v4alpha.VirtualHost\x12.\n\x04vhds\x18\t \x01(\x0b\x32 .envoy.config.route.v4alpha.Vhds\x12/\n\x15internal_only_headers\x18\x03 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12X\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32,.envoy.config.core.v4alpha.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x34\n\x1aresponse_headers_to_remove\x18\x05 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12W\n\x16request_headers_to_add\x18\x06 \x03(\x0b\x32,.envoy.config.core.v4alpha.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x33\n\x19request_headers_to_remove\x18\x08 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12+\n#most_specific_header_mutations_wins\x18\n \x01(\x08\x12\x35\n\x11validate_clusters\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12I\n#max_direct_response_body_size_bytes\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:/\x9a\xc5\x88\x1e*\n(envoy.config.route.v3.RouteConfiguration\"s\n\x04Vhds\x12H\n\rconfig_source\x18\x01 \x01(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:!\x9a\xc5\x88\x1e\x1c\n\x1a\x65nvoy.config.route.v3.VhdsB@\n(io.envoyproxy.envoy.config.route.v4alphaB\nRouteProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ROUTECONFIGURATION = _descriptor.Descriptor(
  name='RouteConfiguration',
  full_name='envoy.config.route.v4alpha.RouteConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.RouteConfiguration.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_hosts', full_name='envoy.config.route.v4alpha.RouteConfiguration.virtual_hosts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vhds', full_name='envoy.config.route.v4alpha.RouteConfiguration.vhds', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_only_headers', full_name='envoy.config.route.v4alpha.RouteConfiguration.internal_only_headers', index=3,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_to_add', full_name='envoy.config.route.v4alpha.RouteConfiguration.response_headers_to_add', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_to_remove', full_name='envoy.config.route.v4alpha.RouteConfiguration.response_headers_to_remove', index=5,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_add', full_name='envoy.config.route.v4alpha.RouteConfiguration.request_headers_to_add', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_remove', full_name='envoy.config.route.v4alpha.RouteConfiguration.request_headers_to_remove', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='most_specific_header_mutations_wins', full_name='envoy.config.route.v4alpha.RouteConfiguration.most_specific_header_mutations_wins', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validate_clusters', full_name='envoy.config.route.v4alpha.RouteConfiguration.validate_clusters', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_direct_response_body_size_bytes', full_name='envoy.config.route.v4alpha.RouteConfiguration.max_direct_response_body_size_bytes', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.config.route.v3.RouteConfiguration',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=1035,
)


_VHDS = _descriptor.Descriptor(
  name='Vhds',
  full_name='envoy.config.route.v4alpha.Vhds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_source', full_name='envoy.config.route.v4alpha.Vhds.config_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\034\n\032envoy.config.route.v3.Vhds',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=1152,
)

_ROUTECONFIGURATION.fields_by_name['virtual_hosts'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._VIRTUALHOST
_ROUTECONFIGURATION.fields_by_name['vhds'].message_type = _VHDS
_ROUTECONFIGURATION.fields_by_name['response_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUEOPTION
_ROUTECONFIGURATION.fields_by_name['request_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUEOPTION
_ROUTECONFIGURATION.fields_by_name['validate_clusters'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ROUTECONFIGURATION.fields_by_name['max_direct_response_body_size_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_VHDS.fields_by_name['config_source'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
DESCRIPTOR.message_types_by_name['RouteConfiguration'] = _ROUTECONFIGURATION
DESCRIPTOR.message_types_by_name['Vhds'] = _VHDS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RouteConfiguration = _reflection.GeneratedProtocolMessageType('RouteConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _ROUTECONFIGURATION,
  '__module__' : 'envoy.config.route.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteConfiguration)
  })
_sym_db.RegisterMessage(RouteConfiguration)

Vhds = _reflection.GeneratedProtocolMessageType('Vhds', (_message.Message,), {
  'DESCRIPTOR' : _VHDS,
  '__module__' : 'envoy.config.route.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.Vhds)
  })
_sym_db.RegisterMessage(Vhds)


DESCRIPTOR._options = None
_ROUTECONFIGURATION.fields_by_name['internal_only_headers']._options = None
_ROUTECONFIGURATION.fields_by_name['response_headers_to_add']._options = None
_ROUTECONFIGURATION.fields_by_name['response_headers_to_remove']._options = None
_ROUTECONFIGURATION.fields_by_name['request_headers_to_add']._options = None
_ROUTECONFIGURATION.fields_by_name['request_headers_to_remove']._options = None
_ROUTECONFIGURATION._options = None
_VHDS.fields_by_name['config_source']._options = None
_VHDS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/compression/brotli/decompressor/v3/brotli.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/compression/brotli/decompressor/v3/brotli.proto',
  package='envoy.extensions.compression.brotli.decompressor.v3',
  syntax='proto3',
  serialized_options=b'\nAio.envoyproxy.envoy.extensions.compression.brotli.decompressor.v3B\013BrotliProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@envoy/extensions/compression/brotli/decompressor/v3/brotli.proto\x12\x33\x65nvoy.extensions.compression.brotli.decompressor.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"r\n\x06\x42rotli\x12(\n disable_ring_buffer_reallocation\x18\x01 \x01(\x08\x12>\n\nchunk_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 BZ\nAio.envoyproxy.envoy.extensions.compression.brotli.decompressor.v3B\x0b\x42rotliProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_BROTLI = _descriptor.Descriptor(
  name='Brotli',
  full_name='envoy.extensions.compression.brotli.decompressor.v3.Brotli',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disable_ring_buffer_reallocation', full_name='envoy.extensions.compression.brotli.decompressor.v3.Brotli.disable_ring_buffer_reallocation', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunk_size', full_name='envoy.extensions.compression.brotli.decompressor.v3.Brotli.chunk_size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t*\007\030\200\200\004(\200 ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=323,
)

_BROTLI.fields_by_name['chunk_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
DESCRIPTOR.message_types_by_name['Brotli'] = _BROTLI
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Brotli = _reflection.GeneratedProtocolMessageType('Brotli', (_message.Message,), {
  'DESCRIPTOR' : _BROTLI,
  '__module__' : 'envoy.extensions.compression.brotli.decompressor.v3.brotli_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.compression.brotli.decompressor.v3.Brotli)
  })
_sym_db.RegisterMessage(Brotli)


DESCRIPTOR._options = None
_BROTLI.fields_by_name['chunk_size']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/expr/v1alpha1/value.proto',
  package='google.api.expr.v1alpha1',
  syntax='proto3',
  serialized_options=b'\n\034com.google.api.expr.v1alpha1B\nValueProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$google/api/expr/v1alpha1/value.proto\x12\x18google.api.expr.v1alpha1\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xc0\x03\n\x05Value\x12\x30\n\nnull_value\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x15\n\x0bint64_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0cuint64_value\x18\x04 \x01(\x04H\x00\x12\x16\n\x0c\x64ouble_value\x18\x05 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x06 \x01(\tH\x00\x12\x15\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00\x12\x39\n\nenum_value\x18\t \x01(\x0b\x32#.google.api.expr.v1alpha1.EnumValueH\x00\x12,\n\x0cobject_value\x18\n \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x37\n\tmap_value\x18\x0b \x01(\x0b\x32\".google.api.expr.v1alpha1.MapValueH\x00\x12\x39\n\nlist_value\x18\x0c \x01(\x0b\x32#.google.api.expr.v1alpha1.ListValueH\x00\x12\x14\n\ntype_value\x18\x0f \x01(\tH\x00\x42\x06\n\x04kind\"(\n\tEnumValue\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05\"<\n\tListValue\x12/\n\x06values\x18\x01 \x03(\x0b\x32\x1f.google.api.expr.v1alpha1.Value\"\xac\x01\n\x08MapValue\x12\x39\n\x07\x65ntries\x18\x01 \x03(\x0b\x32(.google.api.expr.v1alpha1.MapValue.Entry\x1a\x65\n\x05\x45ntry\x12,\n\x03key\x18\x01 \x01(\x0b\x32\x1f.google.api.expr.v1alpha1.Value\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.google.api.expr.v1alpha1.ValueBm\n\x1c\x63om.google.api.expr.v1alpha1B\nValueProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='google.api.expr.v1alpha1.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='null_value', full_name='google.api.expr.v1alpha1.Value.null_value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='google.api.expr.v1alpha1.Value.bool_value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int64_value', full_name='google.api.expr.v1alpha1.Value.int64_value', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uint64_value', full_name='google.api.expr.v1alpha1.Value.uint64_value', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='google.api.expr.v1alpha1.Value.double_value', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='google.api.expr.v1alpha1.Value.string_value', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_value', full_name='google.api.expr.v1alpha1.Value.bytes_value', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enum_value', full_name='google.api.expr.v1alpha1.Value.enum_value', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_value', full_name='google.api.expr.v1alpha1.Value.object_value', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_value', full_name='google.api.expr.v1alpha1.Value.map_value', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_value', full_name='google.api.expr.v1alpha1.Value.list_value', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_value', full_name='google.api.expr.v1alpha1.Value.type_value', index=11,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='google.api.expr.v1alpha1.Value.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=124,
  serialized_end=572,
)


_ENUMVALUE = _descriptor.Descriptor(
  name='EnumValue',
  full_name='google.api.expr.v1alpha1.EnumValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.api.expr.v1alpha1.EnumValue.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1alpha1.EnumValue.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=574,
  serialized_end=614,
)


_LISTVALUE = _descriptor.Descriptor(
  name='ListValue',
  full_name='google.api.expr.v1alpha1.ListValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='google.api.expr.v1alpha1.ListValue.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=676,
)


_MAPVALUE_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='google.api.expr.v1alpha1.MapValue.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.expr.v1alpha1.MapValue.Entry.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1alpha1.MapValue.Entry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=750,
  serialized_end=851,
)

_MAPVALUE = _descriptor.Descriptor(
  name='MapValue',
  full_name='google.api.expr.v1alpha1.MapValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='google.api.expr.v1alpha1.MapValue.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MAPVALUE_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=679,
  serialized_end=851,
)

_VALUE.fields_by_name['null_value'].enum_type = google_dot_protobuf_dot_struct__pb2._NULLVALUE
_VALUE.fields_by_name['enum_value'].message_type = _ENUMVALUE
_VALUE.fields_by_name['object_value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_VALUE.fields_by_name['map_value'].message_type = _MAPVALUE
_VALUE.fields_by_name['list_value'].message_type = _LISTVALUE
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['null_value'])
_VALUE.fields_by_name['null_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['bool_value'])
_VALUE.fields_by_name['bool_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['int64_value'])
_VALUE.fields_by_name['int64_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['uint64_value'])
_VALUE.fields_by_name['uint64_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['double_value'])
_VALUE.fields_by_name['double_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['string_value'])
_VALUE.fields_by_name['string_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['bytes_value'])
_VALUE.fields_by_name['bytes_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['enum_value'])
_VALUE.fields_by_name['enum_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['object_value'])
_VALUE.fields_by_name['object_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['map_value'])
_VALUE.fields_by_name['map_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['list_value'])
_VALUE.fields_by_name['list_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_VALUE.oneofs_by_name['kind'].fields.append(
  _VALUE.fields_by_name['type_value'])
_VALUE.fields_by_name['type_value'].containing_oneof = _VALUE.oneofs_by_name['kind']
_LISTVALUE.fields_by_name['values'].message_type = _VALUE
_MAPVALUE_ENTRY.fields_by_name['key'].message_type = _VALUE
_MAPVALUE_ENTRY.fields_by_name['value'].message_type = _VALUE
_MAPVALUE_ENTRY.containing_type = _MAPVALUE
_MAPVALUE.fields_by_name['entries'].message_type = _MAPVALUE_ENTRY
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
DESCRIPTOR.message_types_by_name['EnumValue'] = _ENUMVALUE
DESCRIPTOR.message_types_by_name['ListValue'] = _LISTVALUE
DESCRIPTOR.message_types_by_name['MapValue'] = _MAPVALUE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
  'DESCRIPTOR' : _VALUE,
  '__module__' : 'google.api.expr.v1alpha1.value_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Value)
  })
_sym_db.RegisterMessage(Value)

EnumValue = _reflection.GeneratedProtocolMessageType('EnumValue', (_message.Message,), {
  'DESCRIPTOR' : _ENUMVALUE,
  '__module__' : 'google.api.expr.v1alpha1.value_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.EnumValue)
  })
_sym_db.RegisterMessage(EnumValue)

ListValue = _reflection.GeneratedProtocolMessageType('ListValue', (_message.Message,), {
  'DESCRIPTOR' : _LISTVALUE,
  '__module__' : 'google.api.expr.v1alpha1.value_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.ListValue)
  })
_sym_db.RegisterMessage(ListValue)

MapValue = _reflection.GeneratedProtocolMessageType('MapValue', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _MAPVALUE_ENTRY,
    '__module__' : 'google.api.expr.v1alpha1.value_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.MapValue.Entry)
    })
  ,
  'DESCRIPTOR' : _MAPVALUE,
  '__module__' : 'google.api.expr.v1alpha1.value_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.MapValue)
  })
_sym_db.RegisterMessage(MapValue)
_sym_db.RegisterMessage(MapValue.Entry)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/v3/http.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/v3/http.proto',
  package='envoy.type.v3',
  syntax='proto3',
  serialized_options=b'\n\033io.envoyproxy.envoy.type.v3B\tHttpProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x65nvoy/type/v3/http.proto\x12\renvoy.type.v3\x1a\x1dudpa/annotations/status.proto*2\n\x0f\x43odecClientType\x12\t\n\x05HTTP1\x10\x00\x12\t\n\x05HTTP2\x10\x01\x12\t\n\x05HTTP3\x10\x02\x42\x32\n\x1bio.envoyproxy.envoy.type.v3B\tHttpProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])

_CODECCLIENTTYPE = _descriptor.EnumDescriptor(
  name='CodecClientType',
  full_name='envoy.type.v3.CodecClientType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HTTP1', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP2', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP3', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=74,
  serialized_end=124,
)
_sym_db.RegisterEnumDescriptor(_CODECCLIENTTYPE)

CodecClientType = enum_type_wrapper.EnumTypeWrapper(_CODECCLIENTTYPE)
HTTP1 = 0
HTTP2 = 1
HTTP3 = 2


DESCRIPTOR.enum_types_by_name['CodecClientType'] = _CODECCLIENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/rocketmq_proxy/v4alpha/rocketmq_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.network.rocketmq_proxy.v4alpha import route_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_rocketmq__proxy_dot_v4alpha_dot_route__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/rocketmq_proxy/v4alpha/rocketmq_proxy.proto',
  package='envoy.extensions.filters.network.rocketmq_proxy.v4alpha',
  syntax='proto3',
  serialized_options=b'\nEio.envoyproxy.envoy.extensions.filters.network.rocketmq_proxy.v4alphaB\022RocketmqProxyProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nLenvoy/extensions/filters/network/rocketmq_proxy/v4alpha/rocketmq_proxy.proto\x12\x37\x65nvoy.extensions.filters.network.rocketmq_proxy.v4alpha\x1a\x43\x65nvoy/extensions/filters/network/rocketmq_proxy/v4alpha/route.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xae\x02\n\rRocketmqProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x61\n\x0croute_config\x18\x02 \x01(\x0b\x32K.envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteConfiguration\x12=\n\x1atransient_object_life_span\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x14\n\x0c\x64\x65velop_mode\x18\x04 \x01(\x08:G\x9a\xc5\x88\x1e\x42\n@envoy.extensions.filters.network.rocketmq_proxy.v3.RocketmqProxyBe\nEio.envoyproxy.envoy.extensions.filters.network.rocketmq_proxy.v4alphaB\x12RocketmqProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_filters_dot_network_dot_rocketmq__proxy_dot_v4alpha_dot_route__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ROCKETMQPROXY = _descriptor.Descriptor(
  name='RocketmqProxy',
  full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RocketmqProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RocketmqProxy.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RocketmqProxy.route_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transient_object_life_span', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RocketmqProxy.transient_object_life_span', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='develop_mode', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RocketmqProxy.develop_mode', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.extensions.filters.network.rocketmq_proxy.v3.RocketmqProxy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=632,
)

_ROCKETMQPROXY.fields_by_name['route_config'].message_type = envoy_dot_extensions_dot_filters_dot_network_dot_rocketmq__proxy_dot_v4alpha_dot_route__pb2._ROUTECONFIGURATION
_ROCKETMQPROXY.fields_by_name['transient_object_life_span'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['RocketmqProxy'] = _ROCKETMQPROXY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RocketmqProxy = _reflection.GeneratedProtocolMessageType('RocketmqProxy', (_message.Message,), {
  'DESCRIPTOR' : _ROCKETMQPROXY,
  '__module__' : 'envoy.extensions.filters.network.rocketmq_proxy.v4alpha.rocketmq_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RocketmqProxy)
  })
_sym_db.RegisterMessage(RocketmqProxy)


DESCRIPTOR._options = None
_ROCKETMQPROXY.fields_by_name['stat_prefix']._options = None
_ROCKETMQPROXY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/core/v3/context_params.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='xds/core/v3/context_params.proto',
  package='xds.core.v3',
  syntax='proto3',
  serialized_options=b'\n\033com.github.udpa.xds.core.v3B\022ContextParamsProtoP\001\272\200\310\321\006\002\010\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n xds/core/v3/context_params.proto\x12\x0bxds.core.v3\x1a\x1dudpa/annotations/status.proto\"v\n\rContextParams\x12\x36\n\x06params\x18\x01 \x03(\x0b\x32&.xds.core.v3.ContextParams.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42;\n\x1b\x63om.github.udpa.xds.core.v3B\x12\x43ontextParamsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_CONTEXTPARAMS_PARAMSENTRY = _descriptor.Descriptor(
  name='ParamsEntry',
  full_name='xds.core.v3.ContextParams.ParamsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='xds.core.v3.ContextParams.ParamsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='xds.core.v3.ContextParams.ParamsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=198,
)

_CONTEXTPARAMS = _descriptor.Descriptor(
  name='ContextParams',
  full_name='xds.core.v3.ContextParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='xds.core.v3.ContextParams.params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONTEXTPARAMS_PARAMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=198,
)

_CONTEXTPARAMS_PARAMSENTRY.containing_type = _CONTEXTPARAMS
_CONTEXTPARAMS.fields_by_name['params'].message_type = _CONTEXTPARAMS_PARAMSENTRY
DESCRIPTOR.message_types_by_name['ContextParams'] = _CONTEXTPARAMS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ContextParams = _reflection.GeneratedProtocolMessageType('ContextParams', (_message.Message,), {

  'ParamsEntry' : _reflection.GeneratedProtocolMessageType('ParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTEXTPARAMS_PARAMSENTRY,
    '__module__' : 'xds.core.v3.context_params_pb2'
    # @@protoc_insertion_point(class_scope:xds.core.v3.ContextParams.ParamsEntry)
    })
  ,
  'DESCRIPTOR' : _CONTEXTPARAMS,
  '__module__' : 'xds.core.v3.context_params_pb2'
  # @@protoc_insertion_point(class_scope:xds.core.v3.ContextParams)
  })
_sym_db.RegisterMessage(ContextParams)
_sym_db.RegisterMessage(ContextParams.ParamsEntry)


DESCRIPTOR._options = None
_CONTEXTPARAMS_PARAMSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/mongo_proxy/v2/mongo_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.filter.fault.v2 import fault_pb2 as envoy_dot_config_dot_filter_dot_fault_dot_v2_dot_fault__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/network/mongo_proxy/v2/mongo_proxy.proto',
  package='envoy.config.filter.network.mongo_proxy.v2',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.config.filter.network.mongo_proxy.v2B\017MongoProxyProtoP\001\362\230\376\217\0051\022/envoy.extensions.filters.network.mongo_proxy.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<envoy/config/filter/network/mongo_proxy/v2/mongo_proxy.proto\x12*envoy.config.filter.network.mongo_proxy.v2\x1a(envoy/config/filter/fault/v2/fault.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x96\x01\n\nMongoProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x12\n\naccess_log\x18\x02 \x01(\t\x12\x37\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32(.envoy.config.filter.fault.v2.FaultDelay\x12\x1d\n\x15\x65mit_dynamic_metadata\x18\x04 \x01(\x08\x42\x8c\x01\n8io.envoyproxy.envoy.config.filter.network.mongo_proxy.v2B\x0fMongoProxyProtoP\x01\xf2\x98\xfe\x8f\x05\x31\x12/envoy.extensions.filters.network.mongo_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_filter_dot_fault_dot_v2_dot_fault__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_MONGOPROXY = _descriptor.Descriptor(
  name='MongoProxy',
  full_name='envoy.config.filter.network.mongo_proxy.v2.MongoProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.config.filter.network.mongo_proxy.v2.MongoProxy.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_log', full_name='envoy.config.filter.network.mongo_proxy.v2.MongoProxy.access_log', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='envoy.config.filter.network.mongo_proxy.v2.MongoProxy.delay', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emit_dynamic_metadata', full_name='envoy.config.filter.network.mongo_proxy.v2.MongoProxy.emit_dynamic_metadata', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=389,
)

_MONGOPROXY.fields_by_name['delay'].message_type = envoy_dot_config_dot_filter_dot_fault_dot_v2_dot_fault__pb2._FAULTDELAY
DESCRIPTOR.message_types_by_name['MongoProxy'] = _MONGOPROXY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MongoProxy = _reflection.GeneratedProtocolMessageType('MongoProxy', (_message.Message,), {
  'DESCRIPTOR' : _MONGOPROXY,
  '__module__' : 'envoy.config.filter.network.mongo_proxy.v2.mongo_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.mongo_proxy.v2.MongoProxy)
  })
_sym_db.RegisterMessage(MongoProxy)


DESCRIPTOR._options = None
_MONGOPROXY.fields_by_name['stat_prefix']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/sni_dynamic_forward_proxy/v3alpha/sni_dynamic_forward_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.dynamic_forward_proxy.v3 import dns_cache_pb2 as envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/sni_dynamic_forward_proxy/v3alpha/sni_dynamic_forward_proxy.proto',
  package='envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha',
  syntax='proto3',
  serialized_options=b'\nPio.envoyproxy.envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alphaB\033SniDynamicForwardProxyProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nbenvoy/extensions/filters/network/sni_dynamic_forward_proxy/v3alpha/sni_dynamic_forward_proxy.proto\x12\x42\x65nvoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha\x1a@envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa9\x01\n\x0c\x46ilterConfig\x12\x64\n\x10\x64ns_cache_config\x18\x01 \x01(\x0b\x32@.envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12!\n\nport_value\x18\x02 \x01(\rB\x0b\xfa\x42\x08*\x06\x18\xff\xff\x03 \x00H\x00\x42\x10\n\x0eport_specifierB\x81\x01\nPio.envoyproxy.envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alphaB\x1bSniDynamicForwardProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_FILTERCONFIG = _descriptor.Descriptor(
  name='FilterConfig',
  full_name='envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha.FilterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_cache_config', full_name='envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha.FilterConfig.dns_cache_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_value', full_name='envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha.FilterConfig.port_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010*\006\030\377\377\003 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='port_specifier', full_name='envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha.FilterConfig.port_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=293,
  serialized_end=462,
)

_FILTERCONFIG.fields_by_name['dns_cache_config'].message_type = envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2._DNSCACHECONFIG
_FILTERCONFIG.oneofs_by_name['port_specifier'].fields.append(
  _FILTERCONFIG.fields_by_name['port_value'])
_FILTERCONFIG.fields_by_name['port_value'].containing_oneof = _FILTERCONFIG.oneofs_by_name['port_specifier']
DESCRIPTOR.message_types_by_name['FilterConfig'] = _FILTERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FilterConfig = _reflection.GeneratedProtocolMessageType('FilterConfig', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCONFIG,
  '__module__' : 'envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha.sni_dynamic_forward_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha.FilterConfig)
  })
_sym_db.RegisterMessage(FilterConfig)


DESCRIPTOR._options = None
_FILTERCONFIG.fields_by_name['dns_cache_config']._options = None
_FILTERCONFIG.fields_by_name['port_value']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/core/v2alpha/health_check_event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/core/v2alpha/health_check_event.proto',
  package='envoy.data.core.v2alpha',
  syntax='proto3',
  serialized_options=b'\n%io.envoyproxy.envoy.data.core.v2alphaB\025HealthCheckEventProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0envoy/data/core/v2alpha/health_check_event.proto\x12\x17\x65nvoy.data.core.v2alpha\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x81\x05\n\x10HealthCheckEvent\x12Q\n\x13health_checker_type\x18\x01 \x01(\x0e\x32*.envoy.data.core.v2alpha.HealthCheckerTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12(\n\x04host\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x1d\n\x0c\x63luster_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12S\n\x15\x65ject_unhealthy_event\x18\x04 \x01(\x0b\x32\x32.envoy.data.core.v2alpha.HealthCheckEjectUnhealthyH\x00\x12K\n\x11\x61\x64\x64_healthy_event\x18\x05 \x01(\x0b\x32..envoy.data.core.v2alpha.HealthCheckAddHealthyH\x00\x12Q\n\x1ahealth_check_failure_event\x18\x07 \x01(\x0b\x32+.envoy.data.core.v2alpha.HealthCheckFailureH\x00\x12M\n\x15\x64\x65graded_healthy_host\x18\x08 \x01(\x0b\x32,.envoy.data.core.v2alpha.DegradedHealthyHostH\x00\x12P\n\x17no_longer_degraded_host\x18\t \x01(\x0b\x32-.envoy.data.core.v2alpha.NoLongerDegradedHostH\x00\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0c\n\x05\x65vent\x12\x03\xf8\x42\x01\"l\n\x19HealthCheckEjectUnhealthy\x12O\n\x0c\x66\x61ilure_type\x18\x01 \x01(\x0e\x32/.envoy.data.core.v2alpha.HealthCheckFailureTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\",\n\x15HealthCheckAddHealthy\x12\x13\n\x0b\x66irst_check\x18\x01 \x01(\x08\"z\n\x12HealthCheckFailure\x12O\n\x0c\x66\x61ilure_type\x18\x01 \x01(\x0e\x32/.envoy.data.core.v2alpha.HealthCheckFailureTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x13\n\x0b\x66irst_check\x18\x02 \x01(\x08\"\x15\n\x13\x44\x65gradedHealthyHost\"\x16\n\x14NoLongerDegradedHost*>\n\x16HealthCheckFailureType\x12\n\n\x06\x41\x43TIVE\x10\x00\x12\x0b\n\x07PASSIVE\x10\x01\x12\x0b\n\x07NETWORK\x10\x02*;\n\x11HealthCheckerType\x12\x08\n\x04HTTP\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\x08\n\x04GRPC\x10\x02\x12\t\n\x05REDIS\x10\x03\x42H\n%io.envoyproxy.envoy.data.core.v2alphaB\x15HealthCheckEventProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_HEALTHCHECKFAILURETYPE = _descriptor.EnumDescriptor(
  name='HealthCheckFailureType',
  full_name='envoy.data.core.v2alpha.HealthCheckFailureType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PASSIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NETWORK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1170,
  serialized_end=1232,
)
_sym_db.RegisterEnumDescriptor(_HEALTHCHECKFAILURETYPE)

HealthCheckFailureType = enum_type_wrapper.EnumTypeWrapper(_HEALTHCHECKFAILURETYPE)
_HEALTHCHECKERTYPE = _descriptor.EnumDescriptor(
  name='HealthCheckerType',
  full_name='envoy.data.core.v2alpha.HealthCheckerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HTTP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TCP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRPC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REDIS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1234,
  serialized_end=1293,
)
_sym_db.RegisterEnumDescriptor(_HEALTHCHECKERTYPE)

HealthCheckerType = enum_type_wrapper.EnumTypeWrapper(_HEALTHCHECKERTYPE)
ACTIVE = 0
PASSIVE = 1
NETWORK = 2
HTTP = 0
TCP = 1
GRPC = 2
REDIS = 3



_HEALTHCHECKEVENT = _descriptor.Descriptor(
  name='HealthCheckEvent',
  full_name='envoy.data.core.v2alpha.HealthCheckEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='health_checker_type', full_name='envoy.data.core.v2alpha.HealthCheckEvent.health_checker_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='envoy.data.core.v2alpha.HealthCheckEvent.host', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.data.core.v2alpha.HealthCheckEvent.cluster_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eject_unhealthy_event', full_name='envoy.data.core.v2alpha.HealthCheckEvent.eject_unhealthy_event', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_healthy_event', full_name='envoy.data.core.v2alpha.HealthCheckEvent.add_healthy_event', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_check_failure_event', full_name='envoy.data.core.v2alpha.HealthCheckEvent.health_check_failure_event', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='degraded_healthy_host', full_name='envoy.data.core.v2alpha.HealthCheckEvent.degraded_healthy_host', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_longer_degraded_host', full_name='envoy.data.core.v2alpha.HealthCheckEvent.no_longer_degraded_host', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='envoy.data.core.v2alpha.HealthCheckEvent.timestamp', index=8,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='envoy.data.core.v2alpha.HealthCheckEvent.event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=200,
  serialized_end=841,
)


_HEALTHCHECKEJECTUNHEALTHY = _descriptor.Descriptor(
  name='HealthCheckEjectUnhealthy',
  full_name='envoy.data.core.v2alpha.HealthCheckEjectUnhealthy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='failure_type', full_name='envoy.data.core.v2alpha.HealthCheckEjectUnhealthy.failure_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=843,
  serialized_end=951,
)


_HEALTHCHECKADDHEALTHY = _descriptor.Descriptor(
  name='HealthCheckAddHealthy',
  full_name='envoy.data.core.v2alpha.HealthCheckAddHealthy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='first_check', full_name='envoy.data.core.v2alpha.HealthCheckAddHealthy.first_check', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=997,
)


_HEALTHCHECKFAILURE = _descriptor.Descriptor(
  name='HealthCheckFailure',
  full_name='envoy.data.core.v2alpha.HealthCheckFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='failure_type', full_name='envoy.data.core.v2alpha.HealthCheckFailure.failure_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_check', full_name='envoy.data.core.v2alpha.HealthCheckFailure.first_check', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=999,
  serialized_end=1121,
)


_DEGRADEDHEALTHYHOST = _descriptor.Descriptor(
  name='DegradedHealthyHost',
  full_name='envoy.data.core.v2alpha.DegradedHealthyHost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1144,
)


_NOLONGERDEGRADEDHOST = _descriptor.Descriptor(
  name='NoLongerDegradedHost',
  full_name='envoy.data.core.v2alpha.NoLongerDegradedHost',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1146,
  serialized_end=1168,
)

_HEALTHCHECKEVENT.fields_by_name['health_checker_type'].enum_type = _HEALTHCHECKERTYPE
_HEALTHCHECKEVENT.fields_by_name['host'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._ADDRESS
_HEALTHCHECKEVENT.fields_by_name['eject_unhealthy_event'].message_type = _HEALTHCHECKEJECTUNHEALTHY
_HEALTHCHECKEVENT.fields_by_name['add_healthy_event'].message_type = _HEALTHCHECKADDHEALTHY
_HEALTHCHECKEVENT.fields_by_name['health_check_failure_event'].message_type = _HEALTHCHECKFAILURE
_HEALTHCHECKEVENT.fields_by_name['degraded_healthy_host'].message_type = _DEGRADEDHEALTHYHOST
_HEALTHCHECKEVENT.fields_by_name['no_longer_degraded_host'].message_type = _NOLONGERDEGRADEDHOST
_HEALTHCHECKEVENT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_HEALTHCHECKEVENT.oneofs_by_name['event'].fields.append(
  _HEALTHCHECKEVENT.fields_by_name['eject_unhealthy_event'])
_HEALTHCHECKEVENT.fields_by_name['eject_unhealthy_event'].containing_oneof = _HEALTHCHECKEVENT.oneofs_by_name['event']
_HEALTHCHECKEVENT.oneofs_by_name['event'].fields.append(
  _HEALTHCHECKEVENT.fields_by_name['add_healthy_event'])
_HEALTHCHECKEVENT.fields_by_name['add_healthy_event'].containing_oneof = _HEALTHCHECKEVENT.oneofs_by_name['event']
_HEALTHCHECKEVENT.oneofs_by_name['event'].fields.append(
  _HEALTHCHECKEVENT.fields_by_name['health_check_failure_event'])
_HEALTHCHECKEVENT.fields_by_name['health_check_failure_event'].containing_oneof = _HEALTHCHECKEVENT.oneofs_by_name['event']
_HEALTHCHECKEVENT.oneofs_by_name['event'].fields.append(
  _HEALTHCHECKEVENT.fields_by_name['degraded_healthy_host'])
_HEALTHCHECKEVENT.fields_by_name['degraded_healthy_host'].containing_oneof = _HEALTHCHECKEVENT.oneofs_by_name['event']
_HEALTHCHECKEVENT.oneofs_by_name['event'].fields.append(
  _HEALTHCHECKEVENT.fields_by_name['no_longer_degraded_host'])
_HEALTHCHECKEVENT.fields_by_name['no_longer_degraded_host'].containing_oneof = _HEALTHCHECKEVENT.oneofs_by_name['event']
_HEALTHCHECKEJECTUNHEALTHY.fields_by_name['failure_type'].enum_type = _HEALTHCHECKFAILURETYPE
_HEALTHCHECKFAILURE.fields_by_name['failure_type'].enum_type = _HEALTHCHECKFAILURETYPE
DESCRIPTOR.message_types_by_name['HealthCheckEvent'] = _HEALTHCHECKEVENT
DESCRIPTOR.message_types_by_name['HealthCheckEjectUnhealthy'] = _HEALTHCHECKEJECTUNHEALTHY
DESCRIPTOR.message_types_by_name['HealthCheckAddHealthy'] = _HEALTHCHECKADDHEALTHY
DESCRIPTOR.message_types_by_name['HealthCheckFailure'] = _HEALTHCHECKFAILURE
DESCRIPTOR.message_types_by_name['DegradedHealthyHost'] = _DEGRADEDHEALTHYHOST
DESCRIPTOR.message_types_by_name['NoLongerDegradedHost'] = _NOLONGERDEGRADEDHOST
DESCRIPTOR.enum_types_by_name['HealthCheckFailureType'] = _HEALTHCHECKFAILURETYPE
DESCRIPTOR.enum_types_by_name['HealthCheckerType'] = _HEALTHCHECKERTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HealthCheckEvent = _reflection.GeneratedProtocolMessageType('HealthCheckEvent', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKEVENT,
  '__module__' : 'envoy.data.core.v2alpha.health_check_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.core.v2alpha.HealthCheckEvent)
  })
_sym_db.RegisterMessage(HealthCheckEvent)

HealthCheckEjectUnhealthy = _reflection.GeneratedProtocolMessageType('HealthCheckEjectUnhealthy', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKEJECTUNHEALTHY,
  '__module__' : 'envoy.data.core.v2alpha.health_check_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.core.v2alpha.HealthCheckEjectUnhealthy)
  })
_sym_db.RegisterMessage(HealthCheckEjectUnhealthy)

HealthCheckAddHealthy = _reflection.GeneratedProtocolMessageType('HealthCheckAddHealthy', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKADDHEALTHY,
  '__module__' : 'envoy.data.core.v2alpha.health_check_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.core.v2alpha.HealthCheckAddHealthy)
  })
_sym_db.RegisterMessage(HealthCheckAddHealthy)

HealthCheckFailure = _reflection.GeneratedProtocolMessageType('HealthCheckFailure', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKFAILURE,
  '__module__' : 'envoy.data.core.v2alpha.health_check_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.core.v2alpha.HealthCheckFailure)
  })
_sym_db.RegisterMessage(HealthCheckFailure)

DegradedHealthyHost = _reflection.GeneratedProtocolMessageType('DegradedHealthyHost', (_message.Message,), {
  'DESCRIPTOR' : _DEGRADEDHEALTHYHOST,
  '__module__' : 'envoy.data.core.v2alpha.health_check_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.core.v2alpha.DegradedHealthyHost)
  })
_sym_db.RegisterMessage(DegradedHealthyHost)

NoLongerDegradedHost = _reflection.GeneratedProtocolMessageType('NoLongerDegradedHost', (_message.Message,), {
  'DESCRIPTOR' : _NOLONGERDEGRADEDHOST,
  '__module__' : 'envoy.data.core.v2alpha.health_check_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.core.v2alpha.NoLongerDegradedHost)
  })
_sym_db.RegisterMessage(NoLongerDegradedHost)


DESCRIPTOR._options = None
_HEALTHCHECKEVENT.oneofs_by_name['event']._options = None
_HEALTHCHECKEVENT.fields_by_name['health_checker_type']._options = None
_HEALTHCHECKEVENT.fields_by_name['cluster_name']._options = None
_HEALTHCHECKEJECTUNHEALTHY.fields_by_name['failure_type']._options = None
_HEALTHCHECKFAILURE.fields_by_name['failure_type']._options = None
# @@protoc_insertion_point(module_scope)
